@@ -24,6 +24,10 @@ help_text = """
 system:
 /ruok - Check if I am OK
 /where - Where am i running?
+
+pi1:
+/sync - sync from mathom
+
 """
 
 def check_allowed(update, context: CallbackContext):
@@ -87,6 +91,7 @@ def main():
     dp.add_handler(CommandHandler("help", help))
     dp.add_handler(CommandHandler("ruok", ruok))
     dp.add_handler(CommandHandler("where", where))
+    dp.add_handler(CommandHandler("sync", sync))
 
     # on noncommand i.e message - print help
     dp.add_handler(MessageHandler(Filters.text, unknown_help))
